==> eslint-config-osedea-4.0.0.tgz: package/lib/rules/core-variables.js <==
// ----------------------------------------------------------------------------
// Variables
// ----------------------------------------------------------------------------

const confusingBrowserGlobals = require('confusing-browser-globals');

module.exports = {
    // enforce or disallow variable initializations at definition
    'init-declarations': 'off', // TODO

    // disallow deletion of variables
    'no-delete-var': 'error',

    // disallow labels that share a name with a variable
    'no-label-var': 'error', // TODO

    // restrict usage of specified global variables
    'no-restricted-globals': ['error', 'isFinite', 'isNaN'].concat(confusingBrowserGlobals),

    // disallow declaration of variables already declared in the outer scope
    'no-shadow': 'error', // TODO

    // disallow shadowing of names such as `arguments`
    'no-shadow-restricted-names': 'error',

    // disallow use of undeclared variables unless mentioned in a `/*global */` block
    'no-undef': ['error', { typeof: true }], // TODO

    // disallow use of undefined when initializing variables
    'no-undef-init': 'error', // TODO

    // disallow use of `undefined` variable
    'no-undefined': 'error', // TODO

    // disallow declaration of variables that are not used in the code
    'no-unused-vars': [
        // TODO
        'warn',
        {
            vars: 'all',
            args: 'all',
            caughtErrors: 'none',
            ignoreRestSiblings: false,
        },
    ],

    // disallow use of variables before they are defined
    'no-use-before-define': 'error',
};

==> eslint-config-osedea-6.2.0.tgz: package/lib/rules/core-variables.js <==
// ----------------------------------------------------------------------------
// Variables
// ----------------------------------------------------------------------------

const confusingBrowserGlobals = require('confusing-browser-globals');

const rules = {
    // enforce or disallow variable initializations at definition
    // REF typescript
    'init-declarations': 'off', // TODO

    // disallow deletion of variables
    'no-delete-var': 'error',

    // disallow labels that share a name with a variable
    'no-label-var': 'error', // TODO

    // restrict usage of specified global variables
    'no-restricted-globals': ['error', 'isFinite', 'isNaN'].concat(confusingBrowserGlobals),

    // disallow declaration of variables already declared in the outer scope
    'no-shadow': 'error', // TODO

    // disallow shadowing of names such as `arguments`
    'no-shadow-restricted-names': 'error',

    // disallow use of undeclared variables unless mentioned in a `/*global */` block
    'no-undef': ['error', { typeof: true }], // TODO

    // disallow use of undefined when initializing variables
    'no-undef-init': 'error', // TODO

    // disallow use of `undefined` variable
    'no-undefined': 'off', // TODO

    // disallow declaration of variables that are not used in the code
    // REF typescript
    'no-unused-vars': [
        // TODO
        'warn',
        {
            vars: 'all',
            args: 'all',
            caughtErrors: 'none',
            ignoreRestSiblings: false,
        },
    ],

    // disallow use of variables before they are defined
    'no-use-before-define': 'error',
};

module.exports = {
    rules,
};
